/*
 * btf.c
 *
 *  Created on: 2016/06/03
 *      Author: ko-ueki
 */
#include "Block.h"
#include <stdint.h>
#include <stdlib.h>
#include "t_stddef.h"
#include "wait_api.h"
#include "analogin_api.h"
#include "btf.h"
#include "blinky.h"

//Colours
#if 0
#define GREEN 0x00FF00
#define BLACK  0x000000
#define RED  0xFF0000
#define BLUE  0x0000FF
#define WHITE  0xFFFFFF
#define YELLOW 0xFFFF00
#define PINK 0xFFC0CB
#define ORANGE 0xFFA500
#define PURPLE 0xCC99FF
#define AQUA 0x00FFFF
#define GRAY 0x999999
#endif

//16bit color
#define GREEN	0x0400
#define BLACK	0x0000
#define RED		0xF800
#define BLUE	0x001F
#define WHITE	0xFFFF
#define YELLOW	0xFFE0
#define PINK	0xFE19
#define ORANGE	0xFD20
#define PURPLE	0x8010
#define AQUA	0x07FF
#define GRAY	0x8410

const int colors[7] = {AQUA, BLUE, ORANGE, GREEN, RED, PURPLE, YELLOW};

typedef struct {
short no;
int color;
} bitmapView_t;

const short RANRAN_SIZE = 58;
const bitmapView_t ranran[58] = {
	{ 11, PINK}, { 18, PINK}, { 20, PINK}, { 29, PINK}, { 30, PINK},
	{ 39, PINK}, { 40, PINK}, { 44, PINK}, { 46, PINK}, { 49, PINK},
	{ 50, PINK}, { 53, PINK}, { 55, PINK}, { 57, PINK}, { 59, PINK},
	{ 60, PINK}, { 63, PINK}, { 65, PINK}, { 67, PINK}, { 69, PINK},
	{ 70, PINK}, { 73, PINK}, { 77, PINK}, { 79, PINK}, { 80, PINK},
	{ 84, PINK}, { 86, PINK}, { 89, PINK}, { 90, PINK}, { 99, PINK},
	{100, PINK}, {109, PINK}, {110, PINK}, {112, PINK}, {117, PINK},
	{119, PINK}, {120, PINK}, {122, PINK}, {127, PINK}, {129, PINK},
	{130, PINK}, {139, PINK}, {140, PINK}, {141, PINK}, {148, PINK},
	{149, PINK}, {150, PINK}, {152, PINK}, {157, PINK}, {159, PINK},
	{160, PINK}, {163, PINK}, {166, PINK}, {169, PINK}, {170, PINK},
	{179, PINK}, {181, PINK}, {188, PINK},
};

const short WARA_SIZE = 62;
const bitmapView_t wara[62] = {
	  { 20, RED}, { 21, RED}, { 28, RED}, { 29, RED}, { 31, RED},
	  { 32, RED}, { 36, RED}, { 37, RED}, { 38, RED}, { 42, RED},
	  { 46, RED}, { 47, RED}, { 53, RED}, { 55, RED}, { 56, RED},
	  { 64, RED}, { 65, RED}, { 70, RED}, { 71, RED}, { 72, RED},
	  { 73, RED}, { 74, RED}, { 75, RED}, { 76, RED}, { 77, RED},
	  { 78, RED}, { 79, RED}, { 84, RED}, { 94, RED}, { 96, RED},
	  { 97, RED}, {105, RED}, {114, RED}, {123, RED}, {132, RED},
	  {136, RED}, {141, RED}, {142, RED}, {144, RED}, {147, RED},
	  {149, RED}, {151, RED}, {153, RED}, {154, RED}, {157, RED},
	  {158, RED}, {159, RED}, {160, RED}, {161, RED}, {162, RED},
	  {163, RED}, {165, RED}, {166, RED}, {167, RED}, {168, RED},
	  {173, RED}, {178, RED}, {183, RED}, {187, RED}, {188, RED},
	  {192, RED}, {197, RED},
};

const short KURIA_SIZE = 31;
const bitmapView_t kuria[31] = {
	  {198, ORANGE}, {197, ORANGE}, {196, ORANGE}, {189, ORANGE}, {186, ORANGE},
	  {176, ORANGE}, {167, ORANGE}, {158, ORANGE}, {154, ORANGE}, {149, ORANGE},
	  {146, ORANGE}, {144, ORANGE}, {136, ORANGE}, {134, ORANGE}, {126, ORANGE},
	  {124, ORANGE}, {114, ORANGE}, {104, ORANGE}, { 95, ORANGE}, { 74, ORANGE},
	  { 73, ORANGE}, { 72, ORANGE}, { 71, ORANGE}, { 70, ORANGE}, { 60, ORANGE},
	  { 53, ORANGE}, { 51, ORANGE}, { 42, ORANGE}, { 32, ORANGE}, { 22, ORANGE},
	  { 13, ORANGE},
};

const short KAPIPARA_SIZE = 70;
const bitmapView_t kapipara[70] = {
	  {  2, ORANGE}, {  7, ORANGE}, { 11, ORANGE}, { 13, ORANGE}, { 14, ORANGE},
	  { 15, ORANGE}, { 16, ORANGE}, { 18, ORANGE}, { 20, ORANGE}, { 23, BLACK },
	  { 27, BLACK }, { 29, ORANGE}, { 30, ORANGE}, { 32, BLACK }, { 34, BLACK },
	  { 36, BLACK }, { 38, BLACK }, { 39, ORANGE}, { 40, ORANGE}, { 42, BLACK },
	  { 45, BLACK }, { 48, BLACK }, { 49, ORANGE}, { 50, ORANGE}, { 55, BLACK },
	  { 59, ORANGE}, { 60, ORANGE}, { 69, ORANGE}, { 70, ORANGE}, { 79, ORANGE},
	  { 80, ORANGE}, { 85, BLACK }, { 89, ORANGE}, { 90, ORANGE}, { 94, BLACK },
	  { 95, BLACK }, { 96, BLACK }, { 99, ORANGE}, {100, ORANGE}, {109, ORANGE},
	  {110, ORANGE}, {111, BLACK }, {112, BLACK }, {113, BLACK }, {116, BLACK },
	  {117, BLACK }, {118, BLACK }, {119, ORANGE}, {120, ORANGE}, {129, ORANGE},
	  {130, ORANGE}, {139, ORANGE}, {141, ORANGE}, {148, ORANGE}, {152, ORANGE},
	  {157, ORANGE}, {163, ORANGE}, {164, ORANGE}, {165, ORANGE}, {166, ORANGE},
	  {173, YELLOW}, {174, YELLOW}, {175, YELLOW}, {176, YELLOW}, {183, YELLOW},
	  {186, YELLOW}, {193, YELLOW}, {194, YELLOW}, {195, YELLOW}, {196, YELLOW},
};

const short ALL_SIZE = 200;
bitmapView_t all[256];
short hantei[10] = {0, 1, 2, 3, 4, 5, 6, 7, 8, 9};
short b[4];
short j = 205, p = 0, blockNum = 0, time = 600, beforeBlock = 0, resultCount = 0;
short bb[4];

extern void lcddelay(int ms);

/*
 * 初期設定
 */
void init(){
	// 事前ブロックの乱数を設定
  	beforeBlock = (short)(rand() % 7);
  	// 全体情報の初期化
  	for(int i = 0; i < 256/*ALL_SIZE*/; i++){
		all[i].no = 0;
		all[i].color = BLACK;
	}
  	// クリアカウントの初期化
  	resultCount = 0;
}

/*
 * 積みブロック判定(回転時)
 */
bool_t tumiBlockKaiten(short index1, short index2, short index3, short index4, int8_t flag){

	if ( (index1 < 0) || (index2 < 0) || (index3 < 0) || (index4 < 0) )
		return false;

	if (flag == 0 && (all[index1].no == 1 || all[index2].no == 1 || all[index3].no == 1 || all[index4].no == 1)){
		return false;
	}
	b[0] = index1;
	b[1] = index2;
	b[2] = index3;
	b[3] = index4;

	return true;
}

/*
 * 棒
 */
bool_t bou(int8_t flag){
	bool_t ret;

	switch(p){
	case 0:
		if (j % 10 == 1){
			// 右柱を突き抜けないように回転後のブロックを左にずらす
			ret = tumiBlockKaiten(j + 1, j, j + 2, j - 1, flag);
		}
		else if (j % 10 == 0){
			// 右柱を突き抜けないように回転後のブロックを左にずらす
			ret = tumiBlockKaiten(j + 1, j, j + 2, j + 3, flag);
		}
		else if (j % 10 == 8){
			// 左柱を突き抜けないように回転後のブロックを右にずらす
			ret = tumiBlockKaiten(j + 1, j, j - 1, j - 2, flag);
		}
		else if (j % 10 == 9){
			// 左柱を突き抜けないように回転後のブロックを右にずらす
			ret = tumiBlockKaiten(j - 1, j, j - 2, j - 3, flag);
		}
		else{
			ret = tumiBlockKaiten(j + 1, j, j - 1, j - 2, flag);
		}

		if(ret == true)
			p = 1;

		break;
	case 1:
		ret = tumiBlockKaiten(j + 10, j, j - 10, j - 20, flag);

		if(ret == true)
			p = 2;

		break;
	case 2:
		if (j % 10 == 1){
			// 右柱を突き抜けないように回転後のブロックを左にずらす
			ret = tumiBlockKaiten(j + 1, j, j + 2, j - 1, flag);
		}
		else if (j % 10 == 0){
			// 右柱を突き抜けないように回転後のブロックを左にずらす
			ret = tumiBlockKaiten(j + 1, j, j + 2, j + 3, flag);
		}
		else if (j % 10 == 8){
			// 左柱を突き抜けないように回転後のブロックを右にずらす
			ret = tumiBlockKaiten(j + 1, j, j - 1, j - 2, flag);
		}
		else if (j % 10 == 9){
			// 左柱を突き抜けないように回転後のブロックを右にずらす
			ret = tumiBlockKaiten(j - 1, j, j - 2, j - 3, flag);
		}
		else {
			ret = tumiBlockKaiten(j + 2, j, j + 1, j - 1, flag);
		}

		if(ret == true)
			p = 3;

		break;
	case 3:
		ret = tumiBlockKaiten(j - 10, j, j + 10, j + 20, flag);

		if(ret == true)
			p = 0;

		break;
	}

	return ret;
}

/*
 * Ｌ字
 */
bool_t eru(int8_t flag){
	bool_t ret;

	switch(p){
	case 0:
		if (j % 10 == 0){
			ret = tumiBlockKaiten(j + 2, j + 1, j, j - 8, flag);
		}
		else if (j % 10 == 9){
			ret = tumiBlockKaiten(j, j - 1, j - 2, j - 10, flag);
		}
		else {
			ret = tumiBlockKaiten(j + 1, j, j - 1, j - 9, flag);
		}

		if(ret == true)
			p = 1;

		break;
	case 1:
		if (j % 10 == 0){
			ret = tumiBlockKaiten(j + 12, j + 1, j + 11, j - 9, flag);
			j += 1;
		}
		else if (j % 10 == 9){
			ret = tumiBlockKaiten(j + 10, j - 1, j + 9, j - 11, flag);
			j -= 1;
		}
		else {
			ret = tumiBlockKaiten(j + 11, j, j + 10, j - 10, flag);
		}

		if(ret == true)
			p = 2;

		break;
	case 2:
		if (j % 10 == 0){
			ret = tumiBlockKaiten(j + 10, j + 1, j, j + 2, flag);
		}
		else if (j % 10 == 9){
			ret = tumiBlockKaiten(j + 8, j - 1, j - 2, j, flag);
		}
		else {
			ret = tumiBlockKaiten(j + 9, j, j - 1, j + 1, flag);
		}

		if(ret == true)
			p = 3;

		break;
	case 3:
		if (j % 10 == 0){
			ret = tumiBlockKaiten(j + 11, j + 1, j - 9, j - 10, flag);
			j += 1;
		}
		else if (j % 10 == 9){
			ret = tumiBlockKaiten(j + 9, j - 1, j - 11, j - 12, flag);
			j -= 1;
		}
		else {
			ret = tumiBlockKaiten(j + 10, j, j - 10, j - 11, flag);
		}

		if(ret == true)
			p = 0;

		break;
	}

	return ret;
}

/*
 * 逆Ｌ字
 */
bool_t rEru(int8_t flag){
	bool_t ret;

	switch(p){
	case 0:
		if (j % 10 == 0){
			ret = tumiBlockKaiten(j + 1, j, j + 2, j + 12, flag);
		}
		else if (j % 10 == 9){
			ret = tumiBlockKaiten(j - 2, j, j - 1, j + 10, flag);
		}
		else {
			ret = tumiBlockKaiten(j + 1, j, j - 1, j + 11, flag);
		}

		if(ret == true)
			p = 1;

		break;
	case 1:
		if (j % 10 == 0){
			ret = tumiBlockKaiten(j + 10, j + 11, j + 1, j - 9, flag);
			j += 1;
		}
		else if (j % 10 == 9){
			ret = tumiBlockKaiten(j + 8, j + 9, j - 1, j - 11, flag);
			j -= 1;
		}
		else {
			ret = tumiBlockKaiten(j + 9, j, j + 10, j - 10, flag);
		}

		if(ret == true)
			p = 2;

		break;
	case 2:
		if (j % 10 == 0){
			ret = tumiBlockKaiten(j + 1, j, j + 2, j - 10, flag);
		}
		else if (j % 10 == 9){
			ret = tumiBlockKaiten(j - 2, j, j - 1, j - 12, flag);
		}
		else {
			ret = tumiBlockKaiten(j - 11, j, j - 1, j + 1, flag);
		}

		if(ret == true)
			p = 3;

		break;
	case 3:
		if (j % 10 == 0){
			ret = tumiBlockKaiten(j + 11, j + 1, j - 9, j - 8, flag);
			j += 1;
		}
		else if (j % 10 == 9){
			ret = tumiBlockKaiten(j + 9, j - 1, j - 11, j - 10, flag);
			j -= 1;
		}
		else {
			ret = tumiBlockKaiten(j + 10, j, j - 10, j - 9, flag);
		}

		if(ret == true)
			p = 0;

		break;
	}

	return ret;
}

/*
 * Ｚ
 */
bool_t zet(int8_t flag){
	bool_t ret;

	switch(p){
	case 0:
		ret = tumiBlockKaiten(j - 1, j, j + 9, j - 10, flag);

		if(ret == true)
			p = 3;

		break;
	case 3:
		if (j % 10 == 9){
			ret = tumiBlockKaiten(j - 1 -1, j -1, j + 10 -1, j + 11 -1, flag);
		}
		else{
			ret = tumiBlockKaiten(j - 1, j, j + 10, j + 11, flag);
		}

		if(ret == true)
			p = 0;

		break;
	}

	return ret;
}

/*
 * 逆Ｚ
 */
bool_t rZet(int8_t flag){
	bool_t ret;

	switch(p){
	case 0:
		ret = tumiBlockKaiten(j - 1, j, j + 10, j - 11, flag);

		if(ret == true)
			p = 3;

		break;
	case 3:
		if (j % 10 == 9){
			ret = tumiBlockKaiten(j + 1 -1 , j -1 , j + 10 -1 , j + 9 -1, flag);
		}
		else {
			ret = tumiBlockKaiten(j + 1, j, j + 10, j + 9, flag);
		}

		if(ret == true)
			p = 0;

		break;
	}

	return ret;
}

/*
 * 凸
 */
bool_t totu(int8_t flag){
	bool_t ret;

	switch(p){
	case 0:
		if (j % 10 == 0){
			ret = tumiBlockKaiten(j + 11, j + 1, j - 9, j, flag);
			j += 1;
		}
		else if (j % 10 == 9){
			ret = tumiBlockKaiten(j + 9, j - 1, j - 11, j - 2, flag);
			j -= 1;
		}
		else {
			ret = tumiBlockKaiten(j - 1, j, j - 10, j + 10, flag);
		}

		if(ret == true)
			p = 1;

		break;
	case 1:
		if (j % 10 == 0){
			ret = tumiBlockKaiten(j + 2, j + 1, j, j - 9, flag);
			j += 1;
		}
		else if (j % 10 == 9){
			ret = tumiBlockKaiten(j, j - 1, j - 2, j - 11, flag);
			j -= 1;
		}
		else {
			ret = tumiBlockKaiten(j - 1, j, j + 1, j - 10, flag);
		}

		if(ret == true)
			p = 2;

		break;
	case 2:
		if (j % 10 == 0){
			ret = tumiBlockKaiten(j + 11, j + 1, j - 9, j + 2, flag);
			j += 1;
		}
		else if (j % 10 == 9){
			ret = tumiBlockKaiten(j + 9, j - 1, j - 11, j, flag);
			j -= 1;
		}
		else {
			ret = tumiBlockKaiten(j + 1, j, j - 10, j + 10, flag);
		}

		if(ret == true)
			p = 3;

		break;
	case 3:
		if (j % 10 == 0){
			ret = tumiBlockKaiten(j, j + 1, j + 2, j + 11, flag);
			j += 1;
		}
		else if (j % 10 == 9){
			ret = tumiBlockKaiten(j, j - 1, j - 2, j + 9, flag);
			j -= 1;
		}
		else {
			ret = tumiBlockKaiten(j - 1, j, j + 1, j + 10, flag);
		}

		if(ret == true)
			p = 0;

		break;
	}

	return ret;
}

/*
 * 四角
 */
bool_t sikaku(){
	b[0] = j - 1;
	b[1] = j;
	b[2] = j + 9;
	b[3] = j + 10;

	return true;
}

/*
 * ブロック回転振り分け
 */
bool_t changeblock(uint8_t blockNum, uint8_t flag){
	bool_t ret;

	switch(blockNum){
	case 0:
		ret = bou(flag);
		break;
	case 1:
		ret = eru(flag);
		break;
	case 2:
		ret = rEru(flag);
		break;
	case 3:
		ret = zet(flag);
		break;
	case 4:
		ret = rZet(flag);
		break;
	case 5:
		ret = totu(flag);
		break;
	case 6:
		ret = sikaku();
		break;
	}

	return ret;
}

/*
 * 柱の描画
 */
void pillar(){
	int i;
	// 柱
	for(i = 0; i < 24; i++){
		// 右側柱
		drawline(i, 0, i, 159, GRAY);
		// 左側柱
		drawline(i + 104, 0, i + 104, 159, GRAY);
	}
	// 事前ブロック表示部
	for (int i = 500; i < 512; i++){
		drawBlock2(i, WHITE);
	}
}

/*
 * ブロック作成処理
 */
void blockCreate(short index1, short index2, short index3, short index4, int color, int cornerColor){
	drawBlock(index1, color, cornerColor);
	drawBlock(index2, color, cornerColor);
	drawBlock(index3, color, cornerColor);
	drawBlock(index4, color, cornerColor);
}

/*
 * 事前情報ブロック作成処理
 */
void berforeBlockCreate(int color){
	for (int i = 500; i < 512; i++){
		drawBlock(i, WHITE, WHITE);
	}
	switch(beforeBlock){
	case 0:
		// 棒
		blockCreate(501, 504, 507, 510, color, WHITE);
		break;
	case 1:
		// L字
		blockCreate(503, 504, 507, 510, color, WHITE);
		break;
	case 2:
		// 逆L字
		blockCreate(504, 505, 507, 510, color, WHITE);
		break;
	case 3:
		// Z
		blockCreate(503, 504, 507, 508, color, WHITE);
		break;
	case 4:
		// 逆Z
		blockCreate(504, 505, 506, 507, color, WHITE);
		break;
	case 5:
		// 凸
		blockCreate(503, 504, 505, 507, color, WHITE);
		break;
	case 6:
		// 四角
		blockCreate(504, 505, 507, 508, color, WHITE);
		break;
	}
}

/*
 * 積みブロック判定(横移動時)
 */
uint8_t tumiBlock(int8_t index){
	if (b[0] < 10 || b[1] < 10 || b[2] < 10 || b[3] < 10){
		return 1;
	}
	if (b[0] + index < 200 && all[b[0] + index].no == 1){
		return 1;
	}
	if (b[1] + index < 200 && all[b[1] + index].no == 1){
		return 1;
	}
	if (b[2] + index < 200 && all[b[2] + index].no == 1){
		return 1;
	}
	if (b[3] + index < 200 && all[b[3] + index].no == 1){
		return 1;
	}
	return 0;
}

/* 下ブロック衝突判定 */
bool_t downspace(short index1, short index2, short index3, short index4)
{
	int i, j;

	for(i = 0; i < 4; i++) {
		for(j = (i+1); j < 4 ; j ++ ) {
			if ( b[i] == (b[j]-10) ) {
				// 前後で同じ座標はOK
				break;
			}
			else {
				// チェックする
				if( all[b[i]-10].no == 1 )
					return false;
			}
		}
	}

	if( ((index1-10) < 0) || ((index2-10) < 0) || ((index3-10) < 0) || ((index4-10) < 0) )
		return false;

	return true;
}

/*
 * ジョイスティック処理
 */
uint8_t joystick(int data){
	if ((data == BUTTON_RIGHT && tumiBlock(-1) == 0) &&
		(b[0] % 10) != 0 && (b[1] % 10) != 0 && (b[2] % 10) != 0 && (b[3] % 10) != 0){
		//　右
		j--;
		b[0]--;
		b[1]--;
		b[2]--;
		b[3]--;
		return 1;
	}
	else if ((data == BUTTON_LEFT && tumiBlock(1) == 0) &&
			(b[0] % 10) != 9 && (b[1] % 10) != 9 && (b[2] % 10) != 9 && (b[3] % 10) != 9){
		//　左
		j++;
		b[0]++;
		b[1]++;
		b[2]++;
		b[3]++;
		return 1;
	}
	else if (data == BUTTON_SELECT){
		// センター
		if( changeblock(blockNum, 0) == true )
			return 1;
		else
			return 0;
	}
	else if (data == BUTTON_DOWN){
		// 下
		time = 0;
		return 0;
	}
	return 0;
}

//ジョイスティック周期割込み処理
bool_t j_work_enable;
void joystick_work(uint8_t button_data){
	if(j_work_enable == false)
		return;

	bb[0] = b[0];
	bb[1] = b[1];
	bb[2] = b[2];
	bb[3] = b[3];

	if (joystick(button_data) == 1){
		// 移動前のブロックを黒で塗りつぶして消す
		blockCreate(bb[0], bb[1], bb[2], bb[3], BLACK, BLACK);
		// 移動後のブロックを表示
		blockCreate(b[0], b[1], b[2], b[3], colors[blockNum], BLACK);
		lcddelay(100);
	}
}

/*
 * ゲーム処理開始
 */
uint8_t btf(){

	p = 3;
	blockNum = beforeBlock;
	beforeBlock = (short)(rand() % 7);
	//blockNum = 0;
	berforeBlockCreate(colors[beforeBlock]);
	changeblock(blockNum, 1);
	while (1){
		// ジョイスティックの入力に猶予を持たせる
		for (int i = 0; i < 20; i++){
			j_work_enable = true; //ジョイスティック入力許可
			wait_ms(time/20);
			j_work_enable = false; // ジョイスティック入力禁止
		}

		// 一段下の空きスペースを確認
		if(downspace(b[0], b[1], b[2], b[3]) == true) {
			// 移動前のブロックを黒で塗りつぶして消す
			blockCreate(b[0], b[1], b[2], b[3], BLACK, BLACK);
			// 一段下へ
			j = j - 10;
			b[0] -= 10;
			b[1] -= 10;
			b[2] -= 10;
			b[3] -= 10;
			// 移動後のブロックを表示
			blockCreate(b[0], b[1], b[2], b[3], colors[blockNum], BLACK);
		}

		//ｳｪｲﾄ時間調整
		if (resultCount <= 3){
			time = 600;
		}
		else if (resultCount <= 6){
			time = 300;
		}
		else {
			time = 0;
		}

		// 最下部またはつまれているブロックまで落ちたら止める
		if (tumiBlock(-10) == 1){
			j = 205;
			p = 3;
			//　新たに詰まれたブロックを記録
			all[b[0]].no = 1;
			all[b[0]].color = colors[blockNum];
			all[b[1]].no = 1;
			all[b[1]].color = colors[blockNum];
			all[b[2]].no = 1;
			all[b[2]].color = colors[blockNum];
			all[b[3]].no = 1;
			all[b[3]].color = colors[blockNum];
			// 終了判定
			if (b[0] >= 200 || b[1] >= 200 || b[2] >= 200 || b[3] >= 200){
				//　ブロック全体を白で再描画
				for (short k = 0; k < ALL_SIZE; k++){
					if (all[k].no == 1){
						drawBlock(k, WHITE, BLACK);
					}
					else{
						drawBlock(k, BLACK, BLACK);
					}
				}
				lcddelay(500);
				/*// 失敗時の画像表示
				for(short k = 0; k < ALL_SIZE; k++){
					all[k].no = 0;
					drawBlock2(k, BLACK);
				}
				for (short k = 0; k < RANRAN_SIZE; k++){
					drawBlock2(ranran[k].no, ranran[k].color);
				}
				lcddelay(500);
				for(short k = 0; k < ALL_SIZE; k++){
					all[k].no = 0;
					drawBlock2(k, WHITE);
				}
				for (short k = 0; k < WARA_SIZE; k++){
					drawBlock2(wara[k].no, wara[k].color);
				}*/
				return 1;
			}
			break;
		}
		// 行がブロックで埋まったら消す判定
		uint8_t flag = 0;
		uint16_t row = 0;
		for(short i = 0; i < 20; i++){
			for (short j = 0; j < 10; j++){
				if (all[j + (i * 10)].no == 0){
					// 一つでも隙間があったらスルー
					flag = 1;
					break;
				}
			}
			// 行がブロックで埋まったら消す
			if (flag == 0){
				row = i * 10;
				// 消えた行の間を詰めるため、情報を移動する
				for (short k = row; k < ALL_SIZE - row; k++){
					all[k].no = all[k + 10].no;
					all[k].color = all[k + 10].color;
				}
				// 新たな最上行を設定
				for (short k = 190; k < ALL_SIZE; k++){
					all[k].no = 0;
					all[k].color = BLACK;
				}
				//　ブロック全体を再描画
				for (short k = 0; k < ALL_SIZE; k++){
					if (all[k].no == 1){
						drawBlock(k, all[k].color, BLACK);
					}
					else{
						drawBlock(k, BLACK, BLACK);
					}
				}
				i = i - 1;
				resultCount++;
				// クリア判定
				if (resultCount >= 10){
					// 画面ブラックアウト
					for(short k = 0; k < ALL_SIZE; k++){
						all[k].no = 0;
						drawBlock(k, BLACK, BLACK);
					}
					// クリア画面を表示
					for(short k = 0; k < KURIA_SIZE; k++){
						drawBlock2(kuria[k].no, kuria[k].color);
					}
					lcddelay(500);
					// 画面ホワイトアウト
					for(short k = 0; k < ALL_SIZE; k++){
						all[k].no = 0;
						drawBlock2(k, WHITE);
					}
					/*for(short k = 0; k < KAPIPARA_SIZE; k++){
						drawBlock2(kapipara[k].no, kapipara[k].color);
					}*/
					return 1;
				}
			}
			flag = 0;
		}
	}
	return 0;
}

/*
 * 再スタート
 */
uint8_t restart(uint32_t *addr0){
	int ADC_Data = ((*addr0 >> 4) & 0xfff) >> 8;
	// ジョイスティックの上が押されたら再スタートする
	if (ADC_Data == 0x07){
		init();
		return 1;
	}
	return 0;
}
