/* kernel_cfg.c */
#include "kernel/kernel_int.h"
#include "kernel_cfg.h"

#if TKERNEL_PRID != 0x07u
#error The kernel does not match this configuration file.
#endif

/*
 *  Include Directives (#include)
 */

#include "chip_timer.h"
#include "syssvc/syslog.h"
#include "syssvc/banner.h"
#include "target_syssvc.h"
#include "chip_serial.h"
#include "syssvc/serial.h"
#include "syssvc/logtask.h"
#include "common.h"
#include "blinky.h"

/*
 *  Task Management Functions
 */

#define TNUM_STSKID	3

const ID _kernel_tmax_tskid = (TMIN_TSKID + TNUM_TSKID - 1);
const ID _kernel_tmax_stskid = (TMIN_TSKID + TNUM_STSKID - 1);

static STK_T _kernel_stack_LOGTASK[COUNT_STK_T(LOGTASK_STACK_SIZE)];
static STK_T _kernel_stack_INIT_MAIN_TASK[COUNT_STK_T(INIT_MAIN_TASK_STACK_SIZE)];
static STK_T _kernel_stack_BLINKY_MAIN_TASK[COUNT_STK_T(BLINKY_MAIN_TASK_STACK_SIZE)];

const TINIB _kernel_tinib_table[TNUM_STSKID] = {
	{ (TA_ACT), (intptr_t)(LOGTASK_PORTID), ((TASK)(logtask_main)), INT_PRIORITY(LOGTASK_PRIORITY), ROUND_STK_T(LOGTASK_STACK_SIZE), _kernel_stack_LOGTASK, (TA_NULL), (NULL) },
	{ (TA_ACT), (intptr_t)(0), ((TASK)(init_main_task)), INT_PRIORITY(INIT_MAIN_TASK_PRI), ROUND_STK_T(INIT_MAIN_TASK_STACK_SIZE), _kernel_stack_INIT_MAIN_TASK, (TA_NULL), (NULL) },
	{ (TA_ACT), (intptr_t)(0), ((TASK)(blinky_main_task)), INT_PRIORITY(BLINKY_MAIN_TASK_PRI), ROUND_STK_T(BLINKY_MAIN_TASK_STACK_SIZE), _kernel_stack_BLINKY_MAIN_TASK, (TA_NULL), (NULL) }
};

TOPPERS_EMPTY_LABEL(TINIB, _kernel_atinib_table);

TCB _kernel_tcb_table[TNUM_TSKID];

const ID _kernel_torder_table[TNUM_STSKID] = {
	LOGTASK, INIT_MAIN_TASK, BLINKY_MAIN_TASK
};

/*
 *  Semaphore Functions
 */

#define TNUM_SSEMID	8

const ID _kernel_tmax_semid = (TMIN_SEMID + TNUM_SEMID - 1);
const ID _kernel_tmax_ssemid = (TMIN_SEMID + TNUM_SSEMID - 1);

const SEMINIB _kernel_seminib_table[TNUM_SSEMID] = {
	{ (TA_TPRI), (0), (1) },
	{ (TA_TPRI), (1), (1) },
	{ (TA_TPRI), (0), (1) },
	{ (TA_TPRI), (1), (1) },
	{ (TA_TPRI), (0), (1) },
	{ (TA_TPRI), (1), (1) },
	{ (TA_TPRI), (0), (1) },
	{ (TA_TPRI), (1), (1) }
};

TOPPERS_EMPTY_LABEL(SEMINIB, _kernel_aseminib_table);

SEMCB _kernel_semcb_table[TNUM_SEMID];

/*
 *  Eventflag Functions
 */

#define TNUM_SFLGID	0

const ID _kernel_tmax_flgid = (TMIN_FLGID + TNUM_FLGID - 1);
const ID _kernel_tmax_sflgid = (TMIN_FLGID + TNUM_SFLGID - 1);

TOPPERS_EMPTY_LABEL(const FLGINIB, _kernel_flginib_table);

TOPPERS_EMPTY_LABEL(FLGINIB, _kernel_aflginib_table);

TOPPERS_EMPTY_LABEL(FLGCB, _kernel_flgcb_table);

/*
 *  Dataqueue Functions
 */

#define TNUM_SDTQID	0

const ID _kernel_tmax_dtqid = (TMIN_DTQID + TNUM_DTQID - 1);
const ID _kernel_tmax_sdtqid = (TMIN_DTQID + TNUM_SDTQID - 1);

TOPPERS_EMPTY_LABEL(const DTQINIB, _kernel_dtqinib_table);

TOPPERS_EMPTY_LABEL(DTQINIB, _kernel_adtqinib_table);

TOPPERS_EMPTY_LABEL(DTQCB, _kernel_dtqcb_table);

/*
 *  Priority Dataqueue Functions
 */

#define TNUM_SPDQID	0

const ID _kernel_tmax_pdqid = (TMIN_PDQID + TNUM_PDQID - 1);
const ID _kernel_tmax_spdqid = (TMIN_PDQID + TNUM_SPDQID - 1);

TOPPERS_EMPTY_LABEL(const PDQINIB, _kernel_pdqinib_table);

TOPPERS_EMPTY_LABEL(PDQINIB, _kernel_apdqinib_table);

TOPPERS_EMPTY_LABEL(PDQCB, _kernel_pdqcb_table);

/*
 *  Mailbox Functions
 */

#define TNUM_SMBXID	0

const ID _kernel_tmax_mbxid = (TMIN_MBXID + TNUM_MBXID - 1);
const ID _kernel_tmax_smbxid = (TMIN_MBXID + TNUM_SMBXID - 1);

TOPPERS_EMPTY_LABEL(const MBXINIB, _kernel_mbxinib_table);

TOPPERS_EMPTY_LABEL(MBXINIB, _kernel_ambxinib_table);

TOPPERS_EMPTY_LABEL(MBXCB, _kernel_mbxcb_table);

/*
 *  Mutex Functions
 */

#define TNUM_SMTXID	0

const ID _kernel_tmax_mtxid = (TMIN_MTXID + TNUM_MTXID - 1);
const ID _kernel_tmax_smtxid = (TMIN_MTXID + TNUM_SMTXID - 1);

TOPPERS_EMPTY_LABEL(const MTXINIB, _kernel_mtxinib_table);

TOPPERS_EMPTY_LABEL(MTXINIB, _kernel_amtxinib_table);

TOPPERS_EMPTY_LABEL(MTXCB, _kernel_mtxcb_table);

/*
 *  Fixed-sized Memorypool Functions
 */

#define TNUM_SMPFID	0

const ID _kernel_tmax_mpfid = (TMIN_MPFID + TNUM_MPFID - 1);
const ID _kernel_tmax_smpfid = (TMIN_MPFID + TNUM_SMPFID - 1);

TOPPERS_EMPTY_LABEL(const MPFINIB, _kernel_mpfinib_table);

TOPPERS_EMPTY_LABEL(MPFINIB, _kernel_ampfinib_table);

TOPPERS_EMPTY_LABEL(MPFCB, _kernel_mpfcb_table);

/*
 *  Cyclic Handler Functions
 */

#define TNUM_SCYCID	1

const ID _kernel_tmax_cycid = (TMIN_CYCID + TNUM_CYCID - 1);
const ID _kernel_tmax_scycid = (TMIN_CYCID + TNUM_SCYCID - 1);

const CYCINIB _kernel_cycinib_table[TNUM_SCYCID] = {
	{ (TA_NULL), (intptr_t)(0), (joystick_cyc), (100), (0) }
};

TOPPERS_EMPTY_LABEL(CYCINIB, _kernel_acycinib_table);

CYCCB _kernel_cyccb_table[TNUM_CYCID];

/*
 *  Alarm Handler Functions
 */

#define TNUM_SALMID	0

const ID _kernel_tmax_almid = (TMIN_ALMID + TNUM_ALMID - 1);
const ID _kernel_tmax_salmid = (TMIN_ALMID + TNUM_SALMID - 1);

TOPPERS_EMPTY_LABEL(const ALMINIB, _kernel_alminib_table);

TOPPERS_EMPTY_LABEL(ALMINIB, _kernel_aalminib_table);

TOPPERS_EMPTY_LABEL(ALMCB, _kernel_almcb_table);

/*
 *  Interrupt Management Functions
 */

const uint_t _kernel_tnum_isr_queue = 2;

const ISR_ENTRY _kernel_isr_queue_list[2] = {
	{ 231, &(_kernel_isr_queue_table[0]) },
	{ 232, &(_kernel_isr_queue_table[1]) }
};

QUEUE _kernel_isr_queue_table[2];

void
_kernel_inthdr_231(void)
{
	i_begin_int(231);
	_kernel_call_isr(&(_kernel_isr_queue_table[0]));
	i_end_int(231);
}

void
_kernel_inthdr_232(void)
{
	i_begin_int(232);
	_kernel_call_isr(&(_kernel_isr_queue_table[1]));
	i_end_int(232);
}

#define TNUM_SISR	2
#define TNUM_ISR	2

const ID _kernel_tmax_isrid = (TMIN_ISRID + TNUM_ISRID - 1);
const uint_t _kernel_tnum_sisr = TNUM_SISR;

const ISRINIB _kernel_sisrinib_table[TNUM_SISR] = {
	{ (TA_NULL), (3), (INTNO_SCIF_RXI_3), (&(_kernel_isr_queue_table[0])), (sio_isr_rxi), (1) },
	{ (TA_NULL), (3), (INTNO_SCIF_TXI_3), (&(_kernel_isr_queue_table[1])), (sio_isr_txi), (1) }
};

TOPPERS_EMPTY_LABEL(ISRINIB, _kernel_aisrinib_table);

ISRCB _kernel_isrcb_table[TNUM_ISR];

#define TNUM_INHNO	3
const uint_t _kernel_tnum_inhno = TNUM_INHNO;

INTHDR_ENTRY(INHNO_TIMER, 134, target_timer_handler)
INTHDR_ENTRY(231, 231, _kernel_inthdr_231)
INTHDR_ENTRY(232, 232, _kernel_inthdr_232)

const INHINIB _kernel_inhinib_table[TNUM_INHNO] = {
	{ (INHNO_TIMER), (TA_NULL), (FP)(INT_ENTRY(INHNO_TIMER, target_timer_handler)) },
	{ (231), (TA_NULL), (FP)(INT_ENTRY(231, _kernel_inthdr_231)) },
	{ (232), (TA_NULL), (FP)(INT_ENTRY(232, _kernel_inthdr_232)) }
};

#define TNUM_INTNO	3
const uint_t _kernel_tnum_intno = TNUM_INTNO;

const INTINIB _kernel_intinib_table[TNUM_INTNO] = {
	{ (INTNO_TIMER), (TA_ENAINT|INTATR_TIMER), (INTPRI_TIMER) },
	{ (INTNO_SCIF_RXI_3), (INTATR_SIO_3), (INTPRI_SIO_3) },
	{ (INTNO_SCIF_TXI_3), (INTATR_SIO_3), (INTPRI_SIO_3) }
};

/*
 *  CPU Exception Management Functions
 */

/*
 *  Stack Area for Non-task Context
 */

#ifdef DEFAULT_ISTK

#define TOPPERS_ISTKSZ		DEFAULT_ISTKSZ
#define TOPPERS_ISTK		DEFAULT_ISTK

#else /* DEAULT_ISTK */

static STK_T				_kernel_istack[COUNT_STK_T(DEFAULT_ISTKSZ)];
#define TOPPERS_ISTKSZ		ROUND_STK_T(DEFAULT_ISTKSZ)
#define TOPPERS_ISTK		_kernel_istack

#endif /* DEAULT_ISTK */

const SIZE		_kernel_istksz = TOPPERS_ISTKSZ;
STK_T *const	_kernel_istk = TOPPERS_ISTK;

#ifdef TOPPERS_ISTKPT
STK_T *const	_kernel_istkpt = TOPPERS_ISTKPT(TOPPERS_ISTK, TOPPERS_ISTKSZ);
#endif /* TOPPERS_ISTKPT */

/*
 *  Memory Area Allocated by Kernel
 */

#define TOPPERS_KMMSZ		0
#define TOPPERS_KMM			NULL

const SIZE		_kernel_kmmsz = TOPPERS_KMMSZ;
MB_T *const		_kernel_kmm = TOPPERS_KMM;

/*
 *  Time Event Management
 */

TMEVTN   _kernel_tmevt_heap[TNUM_TSKID + TNUM_CYCID + TNUM_ALMID];

/*
 *  Module Initialization Function
 */

void
_kernel_initialize_object(void)
{
	_kernel_initialize_task();
	_kernel_initialize_semaphore();
	_kernel_initialize_cyclic();
	_kernel_initialize_interrupt();
	_kernel_initialize_isr();
	_kernel_initialize_exception();
}

/*
 *  Initialization Routine
 */

void
_kernel_call_inirtn(void)
{
	((INIRTN)(target_timer_initialize))((intptr_t)(0));
	((INIRTN)(syslog_initialize))((intptr_t)(0));
	((INIRTN)(print_banner))((intptr_t)(0));
	((INIRTN)(sio_initialize))((intptr_t)(0));
	((INIRTN)(serial_initialize))((intptr_t)(0));
}

/*
 *  Termination Routine
 */

void
_kernel_call_terrtn(void)
{
	((TERRTN)(logtask_terminate))((intptr_t)(0));
	((TERRTN)(target_timer_terminate))((intptr_t)(0));
}



const FP _kernel_exch_tbl[TNUM_EXCH] = {
 	(FP)(_kernel_default_exc_handler), /* 0 */
 	(FP)(_kernel_default_exc_handler), /* 1 */
 	(FP)(_kernel_default_exc_handler), /* 2 */
 	(FP)(_kernel_default_exc_handler), /* 3 */
 	(FP)(_kernel_default_exc_handler), /* 4 */
 	(FP)(_kernel_default_exc_handler), /* 5 */
 	(FP)(_kernel_default_exc_handler), /* 6 */

};


FP _kernel_inh_tbl[TNUM_INH] = {
 	(FP)(_kernel_default_int_handler), /* 0 */
 	(FP)(_kernel_default_int_handler), /* 1 */
 	(FP)(_kernel_default_int_handler), /* 2 */
 	(FP)(_kernel_default_int_handler), /* 3 */
 	(FP)(_kernel_default_int_handler), /* 4 */
 	(FP)(_kernel_default_int_handler), /* 5 */
 	(FP)(_kernel_default_int_handler), /* 6 */
 	(FP)(_kernel_default_int_handler), /* 7 */
 	(FP)(_kernel_default_int_handler), /* 8 */
 	(FP)(_kernel_default_int_handler), /* 9 */
 	(FP)(_kernel_default_int_handler), /* 10 */
 	(FP)(_kernel_default_int_handler), /* 11 */
 	(FP)(_kernel_default_int_handler), /* 12 */
 	(FP)(_kernel_default_int_handler), /* 13 */
 	(FP)(_kernel_default_int_handler), /* 14 */
 	(FP)(_kernel_default_int_handler), /* 15 */
 	(FP)(_kernel_default_int_handler), /* 16 */
 	(FP)(_kernel_default_int_handler), /* 17 */
 	(FP)(_kernel_default_int_handler), /* 18 */
 	(FP)(_kernel_default_int_handler), /* 19 */
 	(FP)(_kernel_default_int_handler), /* 20 */
 	(FP)(_kernel_default_int_handler), /* 21 */
 	(FP)(_kernel_default_int_handler), /* 22 */
 	(FP)(_kernel_default_int_handler), /* 23 */
 	(FP)(_kernel_default_int_handler), /* 24 */
 	(FP)(_kernel_default_int_handler), /* 25 */
 	(FP)(_kernel_default_int_handler), /* 26 */
 	(FP)(_kernel_default_int_handler), /* 27 */
 	(FP)(_kernel_default_int_handler), /* 28 */
 	(FP)(_kernel_default_int_handler), /* 29 */
 	(FP)(_kernel_default_int_handler), /* 30 */
 	(FP)(_kernel_default_int_handler), /* 31 */
 	(FP)(_kernel_default_int_handler), /* 32 */
 	(FP)(_kernel_default_int_handler), /* 33 */
 	(FP)(_kernel_default_int_handler), /* 34 */
 	(FP)(_kernel_default_int_handler), /* 35 */
 	(FP)(_kernel_default_int_handler), /* 36 */
 	(FP)(_kernel_default_int_handler), /* 37 */
 	(FP)(_kernel_default_int_handler), /* 38 */
 	(FP)(_kernel_default_int_handler), /* 39 */
 	(FP)(_kernel_default_int_handler), /* 40 */
 	(FP)(_kernel_default_int_handler), /* 41 */
 	(FP)(_kernel_default_int_handler), /* 42 */
 	(FP)(_kernel_default_int_handler), /* 43 */
 	(FP)(_kernel_default_int_handler), /* 44 */
 	(FP)(_kernel_default_int_handler), /* 45 */
 	(FP)(_kernel_default_int_handler), /* 46 */
 	(FP)(_kernel_default_int_handler), /* 47 */
 	(FP)(_kernel_default_int_handler), /* 48 */
 	(FP)(_kernel_default_int_handler), /* 49 */
 	(FP)(_kernel_default_int_handler), /* 50 */
 	(FP)(_kernel_default_int_handler), /* 51 */
 	(FP)(_kernel_default_int_handler), /* 52 */
 	(FP)(_kernel_default_int_handler), /* 53 */
 	(FP)(_kernel_default_int_handler), /* 54 */
 	(FP)(_kernel_default_int_handler), /* 55 */
 	(FP)(_kernel_default_int_handler), /* 56 */
 	(FP)(_kernel_default_int_handler), /* 57 */
 	(FP)(_kernel_default_int_handler), /* 58 */
 	(FP)(_kernel_default_int_handler), /* 59 */
 	(FP)(_kernel_default_int_handler), /* 60 */
 	(FP)(_kernel_default_int_handler), /* 61 */
 	(FP)(_kernel_default_int_handler), /* 62 */
 	(FP)(_kernel_default_int_handler), /* 63 */
 	(FP)(_kernel_default_int_handler), /* 64 */
 	(FP)(_kernel_default_int_handler), /* 65 */
 	(FP)(_kernel_default_int_handler), /* 66 */
 	(FP)(_kernel_default_int_handler), /* 67 */
 	(FP)(_kernel_default_int_handler), /* 68 */
 	(FP)(_kernel_default_int_handler), /* 69 */
 	(FP)(_kernel_default_int_handler), /* 70 */
 	(FP)(_kernel_default_int_handler), /* 71 */
 	(FP)(_kernel_default_int_handler), /* 72 */
 	(FP)(_kernel_default_int_handler), /* 73 */
 	(FP)(_kernel_default_int_handler), /* 74 */
 	(FP)(_kernel_default_int_handler), /* 75 */
 	(FP)(_kernel_default_int_handler), /* 76 */
 	(FP)(_kernel_default_int_handler), /* 77 */
 	(FP)(_kernel_default_int_handler), /* 78 */
 	(FP)(_kernel_default_int_handler), /* 79 */
 	(FP)(_kernel_default_int_handler), /* 80 */
 	(FP)(_kernel_default_int_handler), /* 81 */
 	(FP)(_kernel_default_int_handler), /* 82 */
 	(FP)(_kernel_default_int_handler), /* 83 */
 	(FP)(_kernel_default_int_handler), /* 84 */
 	(FP)(_kernel_default_int_handler), /* 85 */
 	(FP)(_kernel_default_int_handler), /* 86 */
 	(FP)(_kernel_default_int_handler), /* 87 */
 	(FP)(_kernel_default_int_handler), /* 88 */
 	(FP)(_kernel_default_int_handler), /* 89 */
 	(FP)(_kernel_default_int_handler), /* 90 */
 	(FP)(_kernel_default_int_handler), /* 91 */
 	(FP)(_kernel_default_int_handler), /* 92 */
 	(FP)(_kernel_default_int_handler), /* 93 */
 	(FP)(_kernel_default_int_handler), /* 94 */
 	(FP)(_kernel_default_int_handler), /* 95 */
 	(FP)(_kernel_default_int_handler), /* 96 */
 	(FP)(_kernel_default_int_handler), /* 97 */
 	(FP)(_kernel_default_int_handler), /* 98 */
 	(FP)(_kernel_default_int_handler), /* 99 */
 	(FP)(_kernel_default_int_handler), /* 100 */
 	(FP)(_kernel_default_int_handler), /* 101 */
 	(FP)(_kernel_default_int_handler), /* 102 */
 	(FP)(_kernel_default_int_handler), /* 103 */
 	(FP)(_kernel_default_int_handler), /* 104 */
 	(FP)(_kernel_default_int_handler), /* 105 */
 	(FP)(_kernel_default_int_handler), /* 106 */
 	(FP)(_kernel_default_int_handler), /* 107 */
 	(FP)(_kernel_default_int_handler), /* 108 */
 	(FP)(_kernel_default_int_handler), /* 109 */
 	(FP)(_kernel_default_int_handler), /* 110 */
 	(FP)(_kernel_default_int_handler), /* 111 */
 	(FP)(_kernel_default_int_handler), /* 112 */
 	(FP)(_kernel_default_int_handler), /* 113 */
 	(FP)(_kernel_default_int_handler), /* 114 */
 	(FP)(_kernel_default_int_handler), /* 115 */
 	(FP)(_kernel_default_int_handler), /* 116 */
 	(FP)(_kernel_default_int_handler), /* 117 */
 	(FP)(_kernel_default_int_handler), /* 118 */
 	(FP)(_kernel_default_int_handler), /* 119 */
 	(FP)(_kernel_default_int_handler), /* 120 */
 	(FP)(_kernel_default_int_handler), /* 121 */
 	(FP)(_kernel_default_int_handler), /* 122 */
 	(FP)(_kernel_default_int_handler), /* 123 */
 	(FP)(_kernel_default_int_handler), /* 124 */
 	(FP)(_kernel_default_int_handler), /* 125 */
 	(FP)(_kernel_default_int_handler), /* 126 */
 	(FP)(_kernel_default_int_handler), /* 127 */
 	(FP)(_kernel_default_int_handler), /* 128 */
 	(FP)(_kernel_default_int_handler), /* 129 */
 	(FP)(_kernel_default_int_handler), /* 130 */
 	(FP)(_kernel_default_int_handler), /* 131 */
 	(FP)(_kernel_default_int_handler), /* 132 */
 	(FP)(_kernel_default_int_handler), /* 133 */
 	(FP)(target_timer_handler), /* 134 */
 	(FP)(_kernel_default_int_handler), /* 135 */
 	(FP)(_kernel_default_int_handler), /* 136 */
 	(FP)(_kernel_default_int_handler), /* 137 */
 	(FP)(_kernel_default_int_handler), /* 138 */
 	(FP)(_kernel_default_int_handler), /* 139 */
 	(FP)(_kernel_default_int_handler), /* 140 */
 	(FP)(_kernel_default_int_handler), /* 141 */
 	(FP)(_kernel_default_int_handler), /* 142 */
 	(FP)(_kernel_default_int_handler), /* 143 */
 	(FP)(_kernel_default_int_handler), /* 144 */
 	(FP)(_kernel_default_int_handler), /* 145 */
 	(FP)(_kernel_default_int_handler), /* 146 */
 	(FP)(_kernel_default_int_handler), /* 147 */
 	(FP)(_kernel_default_int_handler), /* 148 */
 	(FP)(_kernel_default_int_handler), /* 149 */
 	(FP)(_kernel_default_int_handler), /* 150 */
 	(FP)(_kernel_default_int_handler), /* 151 */
 	(FP)(_kernel_default_int_handler), /* 152 */
 	(FP)(_kernel_default_int_handler), /* 153 */
 	(FP)(_kernel_default_int_handler), /* 154 */
 	(FP)(_kernel_default_int_handler), /* 155 */
 	(FP)(_kernel_default_int_handler), /* 156 */
 	(FP)(_kernel_default_int_handler), /* 157 */
 	(FP)(_kernel_default_int_handler), /* 158 */
 	(FP)(_kernel_default_int_handler), /* 159 */
 	(FP)(_kernel_default_int_handler), /* 160 */
 	(FP)(_kernel_default_int_handler), /* 161 */
 	(FP)(_kernel_default_int_handler), /* 162 */
 	(FP)(_kernel_default_int_handler), /* 163 */
 	(FP)(_kernel_default_int_handler), /* 164 */
 	(FP)(_kernel_default_int_handler), /* 165 */
 	(FP)(_kernel_default_int_handler), /* 166 */
 	(FP)(_kernel_default_int_handler), /* 167 */
 	(FP)(_kernel_default_int_handler), /* 168 */
 	(FP)(_kernel_default_int_handler), /* 169 */
 	(FP)(_kernel_default_int_handler), /* 170 */
 	(FP)(_kernel_default_int_handler), /* 171 */
 	(FP)(_kernel_default_int_handler), /* 172 */
 	(FP)(_kernel_default_int_handler), /* 173 */
 	(FP)(_kernel_default_int_handler), /* 174 */
 	(FP)(_kernel_default_int_handler), /* 175 */
 	(FP)(_kernel_default_int_handler), /* 176 */
 	(FP)(_kernel_default_int_handler), /* 177 */
 	(FP)(_kernel_default_int_handler), /* 178 */
 	(FP)(_kernel_default_int_handler), /* 179 */
 	(FP)(_kernel_default_int_handler), /* 180 */
 	(FP)(_kernel_default_int_handler), /* 181 */
 	(FP)(_kernel_default_int_handler), /* 182 */
 	(FP)(_kernel_default_int_handler), /* 183 */
 	(FP)(_kernel_default_int_handler), /* 184 */
 	(FP)(_kernel_default_int_handler), /* 185 */
 	(FP)(_kernel_default_int_handler), /* 186 */
 	(FP)(_kernel_default_int_handler), /* 187 */
 	(FP)(_kernel_default_int_handler), /* 188 */
 	(FP)(_kernel_default_int_handler), /* 189 */
 	(FP)(_kernel_default_int_handler), /* 190 */
 	(FP)(_kernel_default_int_handler), /* 191 */
 	(FP)(_kernel_default_int_handler), /* 192 */
 	(FP)(_kernel_default_int_handler), /* 193 */
 	(FP)(_kernel_default_int_handler), /* 194 */
 	(FP)(_kernel_default_int_handler), /* 195 */
 	(FP)(_kernel_default_int_handler), /* 196 */
 	(FP)(_kernel_default_int_handler), /* 197 */
 	(FP)(_kernel_default_int_handler), /* 198 */
 	(FP)(_kernel_default_int_handler), /* 199 */
 	(FP)(_kernel_default_int_handler), /* 200 */
 	(FP)(_kernel_default_int_handler), /* 201 */
 	(FP)(_kernel_default_int_handler), /* 202 */
 	(FP)(_kernel_default_int_handler), /* 203 */
 	(FP)(_kernel_default_int_handler), /* 204 */
 	(FP)(_kernel_default_int_handler), /* 205 */
 	(FP)(_kernel_default_int_handler), /* 206 */
 	(FP)(_kernel_default_int_handler), /* 207 */
 	(FP)(_kernel_default_int_handler), /* 208 */
 	(FP)(_kernel_default_int_handler), /* 209 */
 	(FP)(_kernel_default_int_handler), /* 210 */
 	(FP)(_kernel_default_int_handler), /* 211 */
 	(FP)(_kernel_default_int_handler), /* 212 */
 	(FP)(_kernel_default_int_handler), /* 213 */
 	(FP)(_kernel_default_int_handler), /* 214 */
 	(FP)(_kernel_default_int_handler), /* 215 */
 	(FP)(_kernel_default_int_handler), /* 216 */
 	(FP)(_kernel_default_int_handler), /* 217 */
 	(FP)(_kernel_default_int_handler), /* 218 */
 	(FP)(_kernel_default_int_handler), /* 219 */
 	(FP)(_kernel_default_int_handler), /* 220 */
 	(FP)(_kernel_default_int_handler), /* 221 */
 	(FP)(_kernel_default_int_handler), /* 222 */
 	(FP)(_kernel_default_int_handler), /* 223 */
 	(FP)(_kernel_default_int_handler), /* 224 */
 	(FP)(_kernel_default_int_handler), /* 225 */
 	(FP)(_kernel_default_int_handler), /* 226 */
 	(FP)(_kernel_default_int_handler), /* 227 */
 	(FP)(_kernel_default_int_handler), /* 228 */
 	(FP)(_kernel_default_int_handler), /* 229 */
 	(FP)(_kernel_default_int_handler), /* 230 */
 	(FP)(_kernel_inthdr_231), /* 231 */
 	(FP)(_kernel_inthdr_232), /* 232 */
 	(FP)(_kernel_default_int_handler), /* 233 */
 	(FP)(_kernel_default_int_handler), /* 234 */
 	(FP)(_kernel_default_int_handler), /* 235 */
 	(FP)(_kernel_default_int_handler), /* 236 */
 	(FP)(_kernel_default_int_handler), /* 237 */
 	(FP)(_kernel_default_int_handler), /* 238 */
 	(FP)(_kernel_default_int_handler), /* 239 */
 	(FP)(_kernel_default_int_handler), /* 240 */
 	(FP)(_kernel_default_int_handler), /* 241 */
 	(FP)(_kernel_default_int_handler), /* 242 */
 	(FP)(_kernel_default_int_handler), /* 243 */
 	(FP)(_kernel_default_int_handler), /* 244 */
 	(FP)(_kernel_default_int_handler), /* 245 */
 	(FP)(_kernel_default_int_handler), /* 246 */
 	(FP)(_kernel_default_int_handler), /* 247 */
 	(FP)(_kernel_default_int_handler), /* 248 */
 	(FP)(_kernel_default_int_handler), /* 249 */
 	(FP)(_kernel_default_int_handler), /* 250 */
 	(FP)(_kernel_default_int_handler), /* 251 */
 	(FP)(_kernel_default_int_handler), /* 252 */
 	(FP)(_kernel_default_int_handler), /* 253 */
 	(FP)(_kernel_default_int_handler), /* 254 */
 	(FP)(_kernel_default_int_handler), /* 255 */
 	(FP)(_kernel_default_int_handler), /* 256 */
 	(FP)(_kernel_default_int_handler), /* 257 */
 	(FP)(_kernel_default_int_handler), /* 258 */
 	(FP)(_kernel_default_int_handler), /* 259 */
 	(FP)(_kernel_default_int_handler), /* 260 */
 	(FP)(_kernel_default_int_handler), /* 261 */
 	(FP)(_kernel_default_int_handler), /* 262 */
 	(FP)(_kernel_default_int_handler), /* 263 */
 	(FP)(_kernel_default_int_handler), /* 264 */
 	(FP)(_kernel_default_int_handler), /* 265 */
 	(FP)(_kernel_default_int_handler), /* 266 */
 	(FP)(_kernel_default_int_handler), /* 267 */
 	(FP)(_kernel_default_int_handler), /* 268 */
 	(FP)(_kernel_default_int_handler), /* 269 */
 	(FP)(_kernel_default_int_handler), /* 270 */
 	(FP)(_kernel_default_int_handler), /* 271 */
 	(FP)(_kernel_default_int_handler), /* 272 */
 	(FP)(_kernel_default_int_handler), /* 273 */
 	(FP)(_kernel_default_int_handler), /* 274 */
 	(FP)(_kernel_default_int_handler), /* 275 */
 	(FP)(_kernel_default_int_handler), /* 276 */
 	(FP)(_kernel_default_int_handler), /* 277 */
 	(FP)(_kernel_default_int_handler), /* 278 */
 	(FP)(_kernel_default_int_handler), /* 279 */
 	(FP)(_kernel_default_int_handler), /* 280 */
 	(FP)(_kernel_default_int_handler), /* 281 */
 	(FP)(_kernel_default_int_handler), /* 282 */
 	(FP)(_kernel_default_int_handler), /* 283 */
 	(FP)(_kernel_default_int_handler), /* 284 */
 	(FP)(_kernel_default_int_handler), /* 285 */
 	(FP)(_kernel_default_int_handler), /* 286 */
 	(FP)(_kernel_default_int_handler), /* 287 */
 	(FP)(_kernel_default_int_handler), /* 288 */
 	(FP)(_kernel_default_int_handler), /* 289 */
 	(FP)(_kernel_default_int_handler), /* 290 */
 	(FP)(_kernel_default_int_handler), /* 291 */
 	(FP)(_kernel_default_int_handler), /* 292 */
 	(FP)(_kernel_default_int_handler), /* 293 */
 	(FP)(_kernel_default_int_handler), /* 294 */
 	(FP)(_kernel_default_int_handler), /* 295 */
 	(FP)(_kernel_default_int_handler), /* 296 */
 	(FP)(_kernel_default_int_handler), /* 297 */
 	(FP)(_kernel_default_int_handler), /* 298 */
 	(FP)(_kernel_default_int_handler), /* 299 */
 	(FP)(_kernel_default_int_handler), /* 300 */
 	(FP)(_kernel_default_int_handler), /* 301 */
 	(FP)(_kernel_default_int_handler), /* 302 */
 	(FP)(_kernel_default_int_handler), /* 303 */
 	(FP)(_kernel_default_int_handler), /* 304 */
 	(FP)(_kernel_default_int_handler), /* 305 */
 	(FP)(_kernel_default_int_handler), /* 306 */
 	(FP)(_kernel_default_int_handler), /* 307 */
 	(FP)(_kernel_default_int_handler), /* 308 */
 	(FP)(_kernel_default_int_handler), /* 309 */
 	(FP)(_kernel_default_int_handler), /* 310 */
 	(FP)(_kernel_default_int_handler), /* 311 */
 	(FP)(_kernel_default_int_handler), /* 312 */
 	(FP)(_kernel_default_int_handler), /* 313 */
 	(FP)(_kernel_default_int_handler), /* 314 */
 	(FP)(_kernel_default_int_handler), /* 315 */
 	(FP)(_kernel_default_int_handler), /* 316 */
 	(FP)(_kernel_default_int_handler), /* 317 */
 	(FP)(_kernel_default_int_handler), /* 318 */
 	(FP)(_kernel_default_int_handler), /* 319 */
 	(FP)(_kernel_default_int_handler), /* 320 */
 	(FP)(_kernel_default_int_handler), /* 321 */
 	(FP)(_kernel_default_int_handler), /* 322 */
 	(FP)(_kernel_default_int_handler), /* 323 */
 	(FP)(_kernel_default_int_handler), /* 324 */
 	(FP)(_kernel_default_int_handler), /* 325 */
 	(FP)(_kernel_default_int_handler), /* 326 */
 	(FP)(_kernel_default_int_handler), /* 327 */
 	(FP)(_kernel_default_int_handler), /* 328 */
 	(FP)(_kernel_default_int_handler), /* 329 */
 	(FP)(_kernel_default_int_handler), /* 330 */
 	(FP)(_kernel_default_int_handler), /* 331 */
 	(FP)(_kernel_default_int_handler), /* 332 */
 	(FP)(_kernel_default_int_handler), /* 333 */
 	(FP)(_kernel_default_int_handler), /* 334 */
 	(FP)(_kernel_default_int_handler), /* 335 */
 	(FP)(_kernel_default_int_handler), /* 336 */
 	(FP)(_kernel_default_int_handler), /* 337 */
 	(FP)(_kernel_default_int_handler), /* 338 */
 	(FP)(_kernel_default_int_handler), /* 339 */
 	(FP)(_kernel_default_int_handler), /* 340 */
 	(FP)(_kernel_default_int_handler), /* 341 */
 	(FP)(_kernel_default_int_handler), /* 342 */
 	(FP)(_kernel_default_int_handler), /* 343 */
 	(FP)(_kernel_default_int_handler), /* 344 */
 	(FP)(_kernel_default_int_handler), /* 345 */
 	(FP)(_kernel_default_int_handler), /* 346 */
 	(FP)(_kernel_default_int_handler), /* 347 */
 	(FP)(_kernel_default_int_handler), /* 348 */
 	(FP)(_kernel_default_int_handler), /* 349 */
 	(FP)(_kernel_default_int_handler), /* 350 */
 	(FP)(_kernel_default_int_handler), /* 351 */
 	(FP)(_kernel_default_int_handler), /* 352 */
 	(FP)(_kernel_default_int_handler), /* 353 */
 	(FP)(_kernel_default_int_handler), /* 354 */
 	(FP)(_kernel_default_int_handler), /* 355 */
 	(FP)(_kernel_default_int_handler), /* 356 */
 	(FP)(_kernel_default_int_handler), /* 357 */
 	(FP)(_kernel_default_int_handler), /* 358 */
 	(FP)(_kernel_default_int_handler), /* 359 */
 	(FP)(_kernel_default_int_handler), /* 360 */
 	(FP)(_kernel_default_int_handler), /* 361 */
 	(FP)(_kernel_default_int_handler), /* 362 */
 	(FP)(_kernel_default_int_handler), /* 363 */
 	(FP)(_kernel_default_int_handler), /* 364 */
 	(FP)(_kernel_default_int_handler), /* 365 */
 	(FP)(_kernel_default_int_handler), /* 366 */
 	(FP)(_kernel_default_int_handler), /* 367 */
 	(FP)(_kernel_default_int_handler), /* 368 */
 	(FP)(_kernel_default_int_handler), /* 369 */
 	(FP)(_kernel_default_int_handler), /* 370 */
 	(FP)(_kernel_default_int_handler), /* 371 */
 	(FP)(_kernel_default_int_handler), /* 372 */
 	(FP)(_kernel_default_int_handler), /* 373 */
 	(FP)(_kernel_default_int_handler), /* 374 */
 	(FP)(_kernel_default_int_handler), /* 375 */
 	(FP)(_kernel_default_int_handler), /* 376 */
 	(FP)(_kernel_default_int_handler), /* 377 */
 	(FP)(_kernel_default_int_handler), /* 378 */
 	(FP)(_kernel_default_int_handler), /* 379 */
 	(FP)(_kernel_default_int_handler), /* 380 */
 	(FP)(_kernel_default_int_handler), /* 381 */
 	(FP)(_kernel_default_int_handler), /* 382 */
 	(FP)(_kernel_default_int_handler), /* 383 */
 	(FP)(_kernel_default_int_handler), /* 384 */
 	(FP)(_kernel_default_int_handler), /* 385 */
 	(FP)(_kernel_default_int_handler), /* 386 */
 	(FP)(_kernel_default_int_handler), /* 387 */
 	(FP)(_kernel_default_int_handler), /* 388 */
 	(FP)(_kernel_default_int_handler), /* 389 */
 	(FP)(_kernel_default_int_handler), /* 390 */
 	(FP)(_kernel_default_int_handler), /* 391 */
 	(FP)(_kernel_default_int_handler), /* 392 */
 	(FP)(_kernel_default_int_handler), /* 393 */
 	(FP)(_kernel_default_int_handler), /* 394 */
 	(FP)(_kernel_default_int_handler), /* 395 */
 	(FP)(_kernel_default_int_handler), /* 396 */
 	(FP)(_kernel_default_int_handler), /* 397 */
 	(FP)(_kernel_default_int_handler), /* 398 */
 	(FP)(_kernel_default_int_handler), /* 399 */
 	(FP)(_kernel_default_int_handler), /* 400 */
 	(FP)(_kernel_default_int_handler), /* 401 */
 	(FP)(_kernel_default_int_handler), /* 402 */
 	(FP)(_kernel_default_int_handler), /* 403 */
 	(FP)(_kernel_default_int_handler), /* 404 */
 	(FP)(_kernel_default_int_handler), /* 405 */
 	(FP)(_kernel_default_int_handler), /* 406 */
 	(FP)(_kernel_default_int_handler), /* 407 */
 	(FP)(_kernel_default_int_handler), /* 408 */
 	(FP)(_kernel_default_int_handler), /* 409 */
 	(FP)(_kernel_default_int_handler), /* 410 */
 	(FP)(_kernel_default_int_handler), /* 411 */
 	(FP)(_kernel_default_int_handler), /* 412 */
 	(FP)(_kernel_default_int_handler), /* 413 */
 	(FP)(_kernel_default_int_handler), /* 414 */
 	(FP)(_kernel_default_int_handler), /* 415 */
 	(FP)(_kernel_default_int_handler), /* 416 */
 	(FP)(_kernel_default_int_handler), /* 417 */
 	(FP)(_kernel_default_int_handler), /* 418 */
 	(FP)(_kernel_default_int_handler), /* 419 */
 	(FP)(_kernel_default_int_handler), /* 420 */
 	(FP)(_kernel_default_int_handler), /* 421 */
 	(FP)(_kernel_default_int_handler), /* 422 */
 	(FP)(_kernel_default_int_handler), /* 423 */
 	(FP)(_kernel_default_int_handler), /* 424 */
 	(FP)(_kernel_default_int_handler), /* 425 */
 	(FP)(_kernel_default_int_handler), /* 426 */
 	(FP)(_kernel_default_int_handler), /* 427 */
 	(FP)(_kernel_default_int_handler), /* 428 */
 	(FP)(_kernel_default_int_handler), /* 429 */
 	(FP)(_kernel_default_int_handler), /* 430 */
 	(FP)(_kernel_default_int_handler), /* 431 */
 	(FP)(_kernel_default_int_handler), /* 432 */
 	(FP)(_kernel_default_int_handler), /* 433 */
 	(FP)(_kernel_default_int_handler), /* 434 */
 	(FP)(_kernel_default_int_handler), /* 435 */
 	(FP)(_kernel_default_int_handler), /* 436 */
 	(FP)(_kernel_default_int_handler), /* 437 */
 	(FP)(_kernel_default_int_handler), /* 438 */
 	(FP)(_kernel_default_int_handler), /* 439 */
 	(FP)(_kernel_default_int_handler), /* 440 */
 	(FP)(_kernel_default_int_handler), /* 441 */
 	(FP)(_kernel_default_int_handler), /* 442 */
 	(FP)(_kernel_default_int_handler), /* 443 */
 	(FP)(_kernel_default_int_handler), /* 444 */
 	(FP)(_kernel_default_int_handler), /* 445 */
 	(FP)(_kernel_default_int_handler), /* 446 */
 	(FP)(_kernel_default_int_handler), /* 447 */
 	(FP)(_kernel_default_int_handler), /* 448 */
 	(FP)(_kernel_default_int_handler), /* 449 */
 	(FP)(_kernel_default_int_handler), /* 450 */
 	(FP)(_kernel_default_int_handler), /* 451 */
 	(FP)(_kernel_default_int_handler), /* 452 */
 	(FP)(_kernel_default_int_handler), /* 453 */
 	(FP)(_kernel_default_int_handler), /* 454 */
 	(FP)(_kernel_default_int_handler), /* 455 */
 	(FP)(_kernel_default_int_handler), /* 456 */
 	(FP)(_kernel_default_int_handler), /* 457 */
 	(FP)(_kernel_default_int_handler), /* 458 */
 	(FP)(_kernel_default_int_handler), /* 459 */
 	(FP)(_kernel_default_int_handler), /* 460 */
 	(FP)(_kernel_default_int_handler), /* 461 */
 	(FP)(_kernel_default_int_handler), /* 462 */
 	(FP)(_kernel_default_int_handler), /* 463 */
 	(FP)(_kernel_default_int_handler), /* 464 */
 	(FP)(_kernel_default_int_handler), /* 465 */
 	(FP)(_kernel_default_int_handler), /* 466 */
 	(FP)(_kernel_default_int_handler), /* 467 */
 	(FP)(_kernel_default_int_handler), /* 468 */
 	(FP)(_kernel_default_int_handler), /* 469 */
 	(FP)(_kernel_default_int_handler), /* 470 */
 	(FP)(_kernel_default_int_handler), /* 471 */
 	(FP)(_kernel_default_int_handler), /* 472 */
 	(FP)(_kernel_default_int_handler), /* 473 */
 	(FP)(_kernel_default_int_handler), /* 474 */
 	(FP)(_kernel_default_int_handler), /* 475 */
 	(FP)(_kernel_default_int_handler), /* 476 */
 	(FP)(_kernel_default_int_handler), /* 477 */
 	(FP)(_kernel_default_int_handler), /* 478 */
 	(FP)(_kernel_default_int_handler), /* 479 */
 	(FP)(_kernel_default_int_handler), /* 480 */
 	(FP)(_kernel_default_int_handler), /* 481 */
 	(FP)(_kernel_default_int_handler), /* 482 */
 	(FP)(_kernel_default_int_handler), /* 483 */
 	(FP)(_kernel_default_int_handler), /* 484 */
 	(FP)(_kernel_default_int_handler), /* 485 */
 	(FP)(_kernel_default_int_handler), /* 486 */
 	(FP)(_kernel_default_int_handler), /* 487 */
 	(FP)(_kernel_default_int_handler), /* 488 */
 	(FP)(_kernel_default_int_handler), /* 489 */
 	(FP)(_kernel_default_int_handler), /* 490 */
 	(FP)(_kernel_default_int_handler), /* 491 */
 	(FP)(_kernel_default_int_handler), /* 492 */
 	(FP)(_kernel_default_int_handler), /* 493 */
 	(FP)(_kernel_default_int_handler), /* 494 */
 	(FP)(_kernel_default_int_handler), /* 495 */
 	(FP)(_kernel_default_int_handler), /* 496 */
 	(FP)(_kernel_default_int_handler), /* 497 */
 	(FP)(_kernel_default_int_handler), /* 498 */
 	(FP)(_kernel_default_int_handler), /* 499 */
 	(FP)(_kernel_default_int_handler), /* 500 */
 	(FP)(_kernel_default_int_handler), /* 501 */
 	(FP)(_kernel_default_int_handler), /* 502 */
 	(FP)(_kernel_default_int_handler), /* 503 */
 	(FP)(_kernel_default_int_handler), /* 504 */
 	(FP)(_kernel_default_int_handler), /* 505 */
 	(FP)(_kernel_default_int_handler), /* 506 */
 	(FP)(_kernel_default_int_handler), /* 507 */
 	(FP)(_kernel_default_int_handler), /* 508 */
 	(FP)(_kernel_default_int_handler), /* 509 */
 	(FP)(_kernel_default_int_handler), /* 510 */
 	(FP)(_kernel_default_int_handler), /* 511 */
 	(FP)(_kernel_default_int_handler), /* 512 */
 	(FP)(_kernel_default_int_handler), /* 513 */
 	(FP)(_kernel_default_int_handler), /* 514 */
 	(FP)(_kernel_default_int_handler), /* 515 */
 	(FP)(_kernel_default_int_handler), /* 516 */
 	(FP)(_kernel_default_int_handler), /* 517 */
 	(FP)(_kernel_default_int_handler), /* 518 */
 	(FP)(_kernel_default_int_handler), /* 519 */
 	(FP)(_kernel_default_int_handler), /* 520 */
 	(FP)(_kernel_default_int_handler), /* 521 */
 	(FP)(_kernel_default_int_handler), /* 522 */
 	(FP)(_kernel_default_int_handler), /* 523 */
 	(FP)(_kernel_default_int_handler), /* 524 */
 	(FP)(_kernel_default_int_handler), /* 525 */
 	(FP)(_kernel_default_int_handler), /* 526 */
 	(FP)(_kernel_default_int_handler), /* 527 */
 	(FP)(_kernel_default_int_handler), /* 528 */
 	(FP)(_kernel_default_int_handler), /* 529 */
 	(FP)(_kernel_default_int_handler), /* 530 */
 	(FP)(_kernel_default_int_handler), /* 531 */
 	(FP)(_kernel_default_int_handler), /* 532 */
 	(FP)(_kernel_default_int_handler), /* 533 */
 	(FP)(_kernel_default_int_handler), /* 534 */
 	(FP)(_kernel_default_int_handler), /* 535 */
 	(FP)(_kernel_default_int_handler), /* 536 */
 	(FP)(_kernel_default_int_handler), /* 537 */
 	(FP)(_kernel_default_int_handler), /* 538 */
 	(FP)(_kernel_default_int_handler), /* 539 */
 	(FP)(_kernel_default_int_handler), /* 540 */
 	(FP)(_kernel_default_int_handler), /* 541 */
 	(FP)(_kernel_default_int_handler), /* 542 */
 	(FP)(_kernel_default_int_handler), /* 543 */
 	(FP)(_kernel_default_int_handler), /* 544 */
 	(FP)(_kernel_default_int_handler), /* 545 */
 	(FP)(_kernel_default_int_handler), /* 546 */
 	(FP)(_kernel_default_int_handler), /* 547 */
 	(FP)(_kernel_default_int_handler), /* 548 */
 	(FP)(_kernel_default_int_handler), /* 549 */
 	(FP)(_kernel_default_int_handler), /* 550 */
 	(FP)(_kernel_default_int_handler), /* 551 */
 	(FP)(_kernel_default_int_handler), /* 552 */
 	(FP)(_kernel_default_int_handler), /* 553 */
 	(FP)(_kernel_default_int_handler), /* 554 */
 	(FP)(_kernel_default_int_handler), /* 555 */
 	(FP)(_kernel_default_int_handler), /* 556 */
 	(FP)(_kernel_default_int_handler), /* 557 */
 	(FP)(_kernel_default_int_handler), /* 558 */
 	(FP)(_kernel_default_int_handler), /* 559 */
 	(FP)(_kernel_default_int_handler), /* 560 */
 	(FP)(_kernel_default_int_handler), /* 561 */
 	(FP)(_kernel_default_int_handler), /* 562 */
 	(FP)(_kernel_default_int_handler), /* 563 */
 	(FP)(_kernel_default_int_handler), /* 564 */
 	(FP)(_kernel_default_int_handler), /* 565 */
 	(FP)(_kernel_default_int_handler), /* 566 */
 	(FP)(_kernel_default_int_handler), /* 567 */
 	(FP)(_kernel_default_int_handler), /* 568 */
 	(FP)(_kernel_default_int_handler), /* 569 */
 	(FP)(_kernel_default_int_handler), /* 570 */
 	(FP)(_kernel_default_int_handler), /* 571 */
 	(FP)(_kernel_default_int_handler), /* 572 */
 	(FP)(_kernel_default_int_handler), /* 573 */
 	(FP)(_kernel_default_int_handler), /* 574 */
 	(FP)(_kernel_default_int_handler), /* 575 */
 	(FP)(_kernel_default_int_handler), /* 576 */
 	(FP)(_kernel_default_int_handler), /* 577 */
 	(FP)(_kernel_default_int_handler), /* 578 */
 	(FP)(_kernel_default_int_handler), /* 579 */
 	(FP)(_kernel_default_int_handler), /* 580 */
 	(FP)(_kernel_default_int_handler), /* 581 */
 	(FP)(_kernel_default_int_handler), /* 582 */
 	(FP)(_kernel_default_int_handler), /* 583 */
 	(FP)(_kernel_default_int_handler), /* 584 */
 	(FP)(_kernel_default_int_handler), /* 585 */
 	(FP)(_kernel_default_int_handler), /* 586 */

};


const uint8_t _kernel_cfgint_tbl[TNUM_INH] = {
 	0U, /* 0x000 */
 	0U, /* 0x001 */
 	0U, /* 0x002 */
 	0U, /* 0x003 */
 	0U, /* 0x004 */
 	0U, /* 0x005 */
 	0U, /* 0x006 */
 	0U, /* 0x007 */
 	0U, /* 0x008 */
 	0U, /* 0x009 */
 	0U, /* 0x00a */
 	0U, /* 0x00b */
 	0U, /* 0x00c */
 	0U, /* 0x00d */
 	0U, /* 0x00e */
 	0U, /* 0x00f */
 	0U, /* 0x010 */
 	0U, /* 0x011 */
 	0U, /* 0x012 */
 	0U, /* 0x013 */
 	0U, /* 0x014 */
 	0U, /* 0x015 */
 	0U, /* 0x016 */
 	0U, /* 0x017 */
 	0U, /* 0x018 */
 	0U, /* 0x019 */
 	0U, /* 0x01a */
 	0U, /* 0x01b */
 	0U, /* 0x01c */
 	0U, /* 0x01d */
 	0U, /* 0x01e */
 	0U, /* 0x01f */
 	0U, /* 0x020 */
 	0U, /* 0x021 */
 	0U, /* 0x022 */
 	0U, /* 0x023 */
 	0U, /* 0x024 */
 	0U, /* 0x025 */
 	0U, /* 0x026 */
 	0U, /* 0x027 */
 	0U, /* 0x028 */
 	0U, /* 0x029 */
 	0U, /* 0x02a */
 	0U, /* 0x02b */
 	0U, /* 0x02c */
 	0U, /* 0x02d */
 	0U, /* 0x02e */
 	0U, /* 0x02f */
 	0U, /* 0x030 */
 	0U, /* 0x031 */
 	0U, /* 0x032 */
 	0U, /* 0x033 */
 	0U, /* 0x034 */
 	0U, /* 0x035 */
 	0U, /* 0x036 */
 	0U, /* 0x037 */
 	0U, /* 0x038 */
 	0U, /* 0x039 */
 	0U, /* 0x03a */
 	0U, /* 0x03b */
 	0U, /* 0x03c */
 	0U, /* 0x03d */
 	0U, /* 0x03e */
 	0U, /* 0x03f */
 	0U, /* 0x040 */
 	0U, /* 0x041 */
 	0U, /* 0x042 */
 	0U, /* 0x043 */
 	0U, /* 0x044 */
 	0U, /* 0x045 */
 	0U, /* 0x046 */
 	0U, /* 0x047 */
 	0U, /* 0x048 */
 	0U, /* 0x049 */
 	0U, /* 0x04a */
 	0U, /* 0x04b */
 	0U, /* 0x04c */
 	0U, /* 0x04d */
 	0U, /* 0x04e */
 	0U, /* 0x04f */
 	0U, /* 0x050 */
 	0U, /* 0x051 */
 	0U, /* 0x052 */
 	0U, /* 0x053 */
 	0U, /* 0x054 */
 	0U, /* 0x055 */
 	0U, /* 0x056 */
 	0U, /* 0x057 */
 	0U, /* 0x058 */
 	0U, /* 0x059 */
 	0U, /* 0x05a */
 	0U, /* 0x05b */
 	0U, /* 0x05c */
 	0U, /* 0x05d */
 	0U, /* 0x05e */
 	0U, /* 0x05f */
 	0U, /* 0x060 */
 	0U, /* 0x061 */
 	0U, /* 0x062 */
 	0U, /* 0x063 */
 	0U, /* 0x064 */
 	0U, /* 0x065 */
 	0U, /* 0x066 */
 	0U, /* 0x067 */
 	0U, /* 0x068 */
 	0U, /* 0x069 */
 	0U, /* 0x06a */
 	0U, /* 0x06b */
 	0U, /* 0x06c */
 	0U, /* 0x06d */
 	0U, /* 0x06e */
 	0U, /* 0x06f */
 	0U, /* 0x070 */
 	0U, /* 0x071 */
 	0U, /* 0x072 */
 	0U, /* 0x073 */
 	0U, /* 0x074 */
 	0U, /* 0x075 */
 	0U, /* 0x076 */
 	0U, /* 0x077 */
 	0U, /* 0x078 */
 	0U, /* 0x079 */
 	0U, /* 0x07a */
 	0U, /* 0x07b */
 	0U, /* 0x07c */
 	0U, /* 0x07d */
 	0U, /* 0x07e */
 	0U, /* 0x07f */
 	0U, /* 0x080 */
 	0U, /* 0x081 */
 	0U, /* 0x082 */
 	0U, /* 0x083 */
 	0U, /* 0x084 */
 	0U, /* 0x085 */
 	1U, /* 0x086 */
 	0U, /* 0x087 */
 	0U, /* 0x088 */
 	0U, /* 0x089 */
 	0U, /* 0x08a */
 	0U, /* 0x08b */
 	0U, /* 0x08c */
 	0U, /* 0x08d */
 	0U, /* 0x08e */
 	0U, /* 0x08f */
 	0U, /* 0x090 */
 	0U, /* 0x091 */
 	0U, /* 0x092 */
 	0U, /* 0x093 */
 	0U, /* 0x094 */
 	0U, /* 0x095 */
 	0U, /* 0x096 */
 	0U, /* 0x097 */
 	0U, /* 0x098 */
 	0U, /* 0x099 */
 	0U, /* 0x09a */
 	0U, /* 0x09b */
 	0U, /* 0x09c */
 	0U, /* 0x09d */
 	0U, /* 0x09e */
 	0U, /* 0x09f */
 	0U, /* 0x0a0 */
 	0U, /* 0x0a1 */
 	0U, /* 0x0a2 */
 	0U, /* 0x0a3 */
 	0U, /* 0x0a4 */
 	0U, /* 0x0a5 */
 	0U, /* 0x0a6 */
 	0U, /* 0x0a7 */
 	0U, /* 0x0a8 */
 	0U, /* 0x0a9 */
 	0U, /* 0x0aa */
 	0U, /* 0x0ab */
 	0U, /* 0x0ac */
 	0U, /* 0x0ad */
 	0U, /* 0x0ae */
 	0U, /* 0x0af */
 	0U, /* 0x0b0 */
 	0U, /* 0x0b1 */
 	0U, /* 0x0b2 */
 	0U, /* 0x0b3 */
 	0U, /* 0x0b4 */
 	0U, /* 0x0b5 */
 	0U, /* 0x0b6 */
 	0U, /* 0x0b7 */
 	0U, /* 0x0b8 */
 	0U, /* 0x0b9 */
 	0U, /* 0x0ba */
 	0U, /* 0x0bb */
 	0U, /* 0x0bc */
 	0U, /* 0x0bd */
 	0U, /* 0x0be */
 	0U, /* 0x0bf */
 	0U, /* 0x0c0 */
 	0U, /* 0x0c1 */
 	0U, /* 0x0c2 */
 	0U, /* 0x0c3 */
 	0U, /* 0x0c4 */
 	0U, /* 0x0c5 */
 	0U, /* 0x0c6 */
 	0U, /* 0x0c7 */
 	0U, /* 0x0c8 */
 	0U, /* 0x0c9 */
 	0U, /* 0x0ca */
 	0U, /* 0x0cb */
 	0U, /* 0x0cc */
 	0U, /* 0x0cd */
 	0U, /* 0x0ce */
 	0U, /* 0x0cf */
 	0U, /* 0x0d0 */
 	0U, /* 0x0d1 */
 	0U, /* 0x0d2 */
 	0U, /* 0x0d3 */
 	0U, /* 0x0d4 */
 	0U, /* 0x0d5 */
 	0U, /* 0x0d6 */
 	0U, /* 0x0d7 */
 	0U, /* 0x0d8 */
 	0U, /* 0x0d9 */
 	0U, /* 0x0da */
 	0U, /* 0x0db */
 	0U, /* 0x0dc */
 	0U, /* 0x0dd */
 	0U, /* 0x0de */
 	0U, /* 0x0df */
 	0U, /* 0x0e0 */
 	0U, /* 0x0e1 */
 	0U, /* 0x0e2 */
 	0U, /* 0x0e3 */
 	0U, /* 0x0e4 */
 	0U, /* 0x0e5 */
 	0U, /* 0x0e6 */
 	1U, /* 0x0e7 */
 	1U, /* 0x0e8 */
 	0U, /* 0x0e9 */
 	0U, /* 0x0ea */
 	0U, /* 0x0eb */
 	0U, /* 0x0ec */
 	0U, /* 0x0ed */
 	0U, /* 0x0ee */
 	0U, /* 0x0ef */
 	0U, /* 0x0f0 */
 	0U, /* 0x0f1 */
 	0U, /* 0x0f2 */
 	0U, /* 0x0f3 */
 	0U, /* 0x0f4 */
 	0U, /* 0x0f5 */
 	0U, /* 0x0f6 */
 	0U, /* 0x0f7 */
 	0U, /* 0x0f8 */
 	0U, /* 0x0f9 */
 	0U, /* 0x0fa */
 	0U, /* 0x0fb */
 	0U, /* 0x0fc */
 	0U, /* 0x0fd */
 	0U, /* 0x0fe */
 	0U, /* 0x0ff */
 	0U, /* 0x100 */
 	0U, /* 0x101 */
 	0U, /* 0x102 */
 	0U, /* 0x103 */
 	0U, /* 0x104 */
 	0U, /* 0x105 */
 	0U, /* 0x106 */
 	0U, /* 0x107 */
 	0U, /* 0x108 */
 	0U, /* 0x109 */
 	0U, /* 0x10a */
 	0U, /* 0x10b */
 	0U, /* 0x10c */
 	0U, /* 0x10d */
 	0U, /* 0x10e */
 	0U, /* 0x10f */
 	0U, /* 0x110 */
 	0U, /* 0x111 */
 	0U, /* 0x112 */
 	0U, /* 0x113 */
 	0U, /* 0x114 */
 	0U, /* 0x115 */
 	0U, /* 0x116 */
 	0U, /* 0x117 */
 	0U, /* 0x118 */
 	0U, /* 0x119 */
 	0U, /* 0x11a */
 	0U, /* 0x11b */
 	0U, /* 0x11c */
 	0U, /* 0x11d */
 	0U, /* 0x11e */
 	0U, /* 0x11f */
 	0U, /* 0x120 */
 	0U, /* 0x121 */
 	0U, /* 0x122 */
 	0U, /* 0x123 */
 	0U, /* 0x124 */
 	0U, /* 0x125 */
 	0U, /* 0x126 */
 	0U, /* 0x127 */
 	0U, /* 0x128 */
 	0U, /* 0x129 */
 	0U, /* 0x12a */
 	0U, /* 0x12b */
 	0U, /* 0x12c */
 	0U, /* 0x12d */
 	0U, /* 0x12e */
 	0U, /* 0x12f */
 	0U, /* 0x130 */
 	0U, /* 0x131 */
 	0U, /* 0x132 */
 	0U, /* 0x133 */
 	0U, /* 0x134 */
 	0U, /* 0x135 */
 	0U, /* 0x136 */
 	0U, /* 0x137 */
 	0U, /* 0x138 */
 	0U, /* 0x139 */
 	0U, /* 0x13a */
 	0U, /* 0x13b */
 	0U, /* 0x13c */
 	0U, /* 0x13d */
 	0U, /* 0x13e */
 	0U, /* 0x13f */
 	0U, /* 0x140 */
 	0U, /* 0x141 */
 	0U, /* 0x142 */
 	0U, /* 0x143 */
 	0U, /* 0x144 */
 	0U, /* 0x145 */
 	0U, /* 0x146 */
 	0U, /* 0x147 */
 	0U, /* 0x148 */
 	0U, /* 0x149 */
 	0U, /* 0x14a */
 	0U, /* 0x14b */
 	0U, /* 0x14c */
 	0U, /* 0x14d */
 	0U, /* 0x14e */
 	0U, /* 0x14f */
 	0U, /* 0x150 */
 	0U, /* 0x151 */
 	0U, /* 0x152 */
 	0U, /* 0x153 */
 	0U, /* 0x154 */
 	0U, /* 0x155 */
 	0U, /* 0x156 */
 	0U, /* 0x157 */
 	0U, /* 0x158 */
 	0U, /* 0x159 */
 	0U, /* 0x15a */
 	0U, /* 0x15b */
 	0U, /* 0x15c */
 	0U, /* 0x15d */
 	0U, /* 0x15e */
 	0U, /* 0x15f */
 	0U, /* 0x160 */
 	0U, /* 0x161 */
 	0U, /* 0x162 */
 	0U, /* 0x163 */
 	0U, /* 0x164 */
 	0U, /* 0x165 */
 	0U, /* 0x166 */
 	0U, /* 0x167 */
 	0U, /* 0x168 */
 	0U, /* 0x169 */
 	0U, /* 0x16a */
 	0U, /* 0x16b */
 	0U, /* 0x16c */
 	0U, /* 0x16d */
 	0U, /* 0x16e */
 	0U, /* 0x16f */
 	0U, /* 0x170 */
 	0U, /* 0x171 */
 	0U, /* 0x172 */
 	0U, /* 0x173 */
 	0U, /* 0x174 */
 	0U, /* 0x175 */
 	0U, /* 0x176 */
 	0U, /* 0x177 */
 	0U, /* 0x178 */
 	0U, /* 0x179 */
 	0U, /* 0x17a */
 	0U, /* 0x17b */
 	0U, /* 0x17c */
 	0U, /* 0x17d */
 	0U, /* 0x17e */
 	0U, /* 0x17f */
 	0U, /* 0x180 */
 	0U, /* 0x181 */
 	0U, /* 0x182 */
 	0U, /* 0x183 */
 	0U, /* 0x184 */
 	0U, /* 0x185 */
 	0U, /* 0x186 */
 	0U, /* 0x187 */
 	0U, /* 0x188 */
 	0U, /* 0x189 */
 	0U, /* 0x18a */
 	0U, /* 0x18b */
 	0U, /* 0x18c */
 	0U, /* 0x18d */
 	0U, /* 0x18e */
 	0U, /* 0x18f */
 	0U, /* 0x190 */
 	0U, /* 0x191 */
 	0U, /* 0x192 */
 	0U, /* 0x193 */
 	0U, /* 0x194 */
 	0U, /* 0x195 */
 	0U, /* 0x196 */
 	0U, /* 0x197 */
 	0U, /* 0x198 */
 	0U, /* 0x199 */
 	0U, /* 0x19a */
 	0U, /* 0x19b */
 	0U, /* 0x19c */
 	0U, /* 0x19d */
 	0U, /* 0x19e */
 	0U, /* 0x19f */
 	0U, /* 0x1a0 */
 	0U, /* 0x1a1 */
 	0U, /* 0x1a2 */
 	0U, /* 0x1a3 */
 	0U, /* 0x1a4 */
 	0U, /* 0x1a5 */
 	0U, /* 0x1a6 */
 	0U, /* 0x1a7 */
 	0U, /* 0x1a8 */
 	0U, /* 0x1a9 */
 	0U, /* 0x1aa */
 	0U, /* 0x1ab */
 	0U, /* 0x1ac */
 	0U, /* 0x1ad */
 	0U, /* 0x1ae */
 	0U, /* 0x1af */
 	0U, /* 0x1b0 */
 	0U, /* 0x1b1 */
 	0U, /* 0x1b2 */
 	0U, /* 0x1b3 */
 	0U, /* 0x1b4 */
 	0U, /* 0x1b5 */
 	0U, /* 0x1b6 */
 	0U, /* 0x1b7 */
 	0U, /* 0x1b8 */
 	0U, /* 0x1b9 */
 	0U, /* 0x1ba */
 	0U, /* 0x1bb */
 	0U, /* 0x1bc */
 	0U, /* 0x1bd */
 	0U, /* 0x1be */
 	0U, /* 0x1bf */
 	0U, /* 0x1c0 */
 	0U, /* 0x1c1 */
 	0U, /* 0x1c2 */
 	0U, /* 0x1c3 */
 	0U, /* 0x1c4 */
 	0U, /* 0x1c5 */
 	0U, /* 0x1c6 */
 	0U, /* 0x1c7 */
 	0U, /* 0x1c8 */
 	0U, /* 0x1c9 */
 	0U, /* 0x1ca */
 	0U, /* 0x1cb */
 	0U, /* 0x1cc */
 	0U, /* 0x1cd */
 	0U, /* 0x1ce */
 	0U, /* 0x1cf */
 	0U, /* 0x1d0 */
 	0U, /* 0x1d1 */
 	0U, /* 0x1d2 */
 	0U, /* 0x1d3 */
 	0U, /* 0x1d4 */
 	0U, /* 0x1d5 */
 	0U, /* 0x1d6 */
 	0U, /* 0x1d7 */
 	0U, /* 0x1d8 */
 	0U, /* 0x1d9 */
 	0U, /* 0x1da */
 	0U, /* 0x1db */
 	0U, /* 0x1dc */
 	0U, /* 0x1dd */
 	0U, /* 0x1de */
 	0U, /* 0x1df */
 	0U, /* 0x1e0 */
 	0U, /* 0x1e1 */
 	0U, /* 0x1e2 */
 	0U, /* 0x1e3 */
 	0U, /* 0x1e4 */
 	0U, /* 0x1e5 */
 	0U, /* 0x1e6 */
 	0U, /* 0x1e7 */
 	0U, /* 0x1e8 */
 	0U, /* 0x1e9 */
 	0U, /* 0x1ea */
 	0U, /* 0x1eb */
 	0U, /* 0x1ec */
 	0U, /* 0x1ed */
 	0U, /* 0x1ee */
 	0U, /* 0x1ef */
 	0U, /* 0x1f0 */
 	0U, /* 0x1f1 */
 	0U, /* 0x1f2 */
 	0U, /* 0x1f3 */
 	0U, /* 0x1f4 */
 	0U, /* 0x1f5 */
 	0U, /* 0x1f6 */
 	0U, /* 0x1f7 */
 	0U, /* 0x1f8 */
 	0U, /* 0x1f9 */
 	0U, /* 0x1fa */
 	0U, /* 0x1fb */
 	0U, /* 0x1fc */
 	0U, /* 0x1fd */
 	0U, /* 0x1fe */
 	0U, /* 0x1ff */
 	0U, /* 0x200 */
 	0U, /* 0x201 */
 	0U, /* 0x202 */
 	0U, /* 0x203 */
 	0U, /* 0x204 */
 	0U, /* 0x205 */
 	0U, /* 0x206 */
 	0U, /* 0x207 */
 	0U, /* 0x208 */
 	0U, /* 0x209 */
 	0U, /* 0x20a */
 	0U, /* 0x20b */
 	0U, /* 0x20c */
 	0U, /* 0x20d */
 	0U, /* 0x20e */
 	0U, /* 0x20f */
 	0U, /* 0x210 */
 	0U, /* 0x211 */
 	0U, /* 0x212 */
 	0U, /* 0x213 */
 	0U, /* 0x214 */
 	0U, /* 0x215 */
 	0U, /* 0x216 */
 	0U, /* 0x217 */
 	0U, /* 0x218 */
 	0U, /* 0x219 */
 	0U, /* 0x21a */
 	0U, /* 0x21b */
 	0U, /* 0x21c */
 	0U, /* 0x21d */
 	0U, /* 0x21e */
 	0U, /* 0x21f */
 	0U, /* 0x220 */
 	0U, /* 0x221 */
 	0U, /* 0x222 */
 	0U, /* 0x223 */
 	0U, /* 0x224 */
 	0U, /* 0x225 */
 	0U, /* 0x226 */
 	0U, /* 0x227 */
 	0U, /* 0x228 */
 	0U, /* 0x229 */
 	0U, /* 0x22a */
 	0U, /* 0x22b */
 	0U, /* 0x22c */
 	0U, /* 0x22d */
 	0U, /* 0x22e */
 	0U, /* 0x22f */
 	0U, /* 0x230 */
 	0U, /* 0x231 */
 	0U, /* 0x232 */
 	0U, /* 0x233 */
 	0U, /* 0x234 */
 	0U, /* 0x235 */
 	0U, /* 0x236 */
 	0U, /* 0x237 */
 	0U, /* 0x238 */
 	0U, /* 0x239 */
 	0U, /* 0x23a */
 	0U, /* 0x23b */
 	0U, /* 0x23c */
 	0U, /* 0x23d */
 	0U, /* 0x23e */
 	0U, /* 0x23f */
 	0U, /* 0x240 */
 	0U, /* 0x241 */
 	0U, /* 0x242 */
 	0U, /* 0x243 */
 	0U, /* 0x244 */
 	0U, /* 0x245 */
 	0U, /* 0x246 */
 	0U, /* 0x247 */
 	0U, /* 0x248 */
 	0U, /* 0x249 */
 	0U, /* 0x586 */

};

